@@ -13,7 +13,7 @@ class lifeline(Variable):
     def formula(spm_unit, period, parameters):
         max_amount = parameters(period).fcc.lifeline.amount * 12
         phone_broadband_cost = add(
-            spm_unit, period, "phone_cost", "broadband_cost"
+            spm_unit, period, ["phone_cost", "broadband_cost"]
         )
         amount_if_eligible = min_(phone_broadband_cost, max_amount)
         eligible = spm_unit("is_lifeline_eligible", period)
