@@ -139,8 +139,8 @@ class e00200(Variable):
     documentation = "Wages, salaries, and tips net of pension contributions"
     unit = USD
 
-    def formula(tax_unit, period, parameters):
-        return tax_unit("employment_income", period)
+    def formula(person, period, parameters):
+        return person("employment_income", period)
 
 
 class filer_e00200(Variable):
@@ -180,6 +180,9 @@ class e00300(Variable):
     documentation = "Taxable interest income"
     unit = USD
 
+    def formula(person, period, parameters):
+        return person("interest_income", period)
+
 
 class filer_e00300(Variable):
     value_type = float
@@ -220,6 +223,9 @@ class e00600(Variable):
     documentation = "Ordinary dividends included in AGI"
     unit = USD
 
+    def formula(person, period, parameters):
+        return person("dividend_income", period)
+
 
 class filer_e00600(Variable):
     value_type = float
@@ -296,6 +302,9 @@ class e00900(Variable):
     documentation = "Sch C business net profit/loss"
     unit = USD
 
+    def formula(person, period, parameters):
+        return person("self_employment_income", period)
+
 
 class filer_e00900(Variable):
     value_type = float
